@@ -4,16 +4,20 @@ use strict;
 use warnings;
 
 use Carp;
-use Object::InsideOut;
+use Object::InsideOut qw/ WWW::Ohloh::API::Role::Fetchable
+  WWW::Ohloh::API::Role::LoadXML /;
 use XML::LibXML;
 use Readonly;
 use Scalar::Util qw/ weaken /;
 use Date::Parse;
 use Time::Piece;
+use Digest::MD5 qw/ md5_hex /;
 
 use WWW::Ohloh::API::StackEntry;
 
-our $VERSION = '0.3.2';
+use Params::Validate qw/ validate_with /;
+
+our $VERSION = '1.0_0';
 
 my @ohloh_of : Field : Arg(ohloh);
 my @request_url_of : Field : Arg(request_url) : Get( request_url );
@@ -36,10 +40,12 @@ my @account_of : Field;
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-sub _init : Init {
-    my $self = shift;
+sub element_name { return 'stack'; }
 
-    my $dom = $xml_of[$$self] or return;
+#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+sub load_xml {
+    my ( $self, $dom ) = @_;
 
     for my $f (qw/ id project_count account_id /) {
         my $method = "_set_$f";
@@ -62,8 +68,26 @@ sub _init : Init {
             ohloh => $ohloh_of[$$self],
             xml   => $_,
           ) => $dom->findnodes('stack_entries/stack_entry') ];
+}
 
-    return;
+#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+sub generate_query_url : Chained(bottom up) {
+    my ( $self, @args ) = @_;
+
+    my %param = validate_with(
+        params      => \@args,
+        spec        => { id => 1 },
+        allow_extra => 1
+    );
+    my $id = $param{id};
+    delete $param{id};
+
+    if ( index( $id, '@' ) > -1 ) {
+        $id = md5_hex($id);
+    }
+
+    return ( "accounts/$id/stacks/default.xml", ohloh => $param{ohloh} );
 }
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -112,7 +136,7 @@ sub account {
 
     if ($retrieve) {
         $account_of[$$self] ||=
-          $ohloh_of[$$self]->get_account( id => $self->account_id );
+          $ohloh_of[$$self]->fetch_account( $self->account_id );
     }
 
     return $account_of[$$self];
@@ -140,7 +164,7 @@ my $ohloh = Fake::Ohloh->new;
 
 $ohloh->stash( 'yadah', 'stack.xml' );
 
-my $thingy = $ohloh->get_account_stack( 123 );
+my $thingy = $ohloh->fetch_account_stack( 123 );
 
 =end test
 
@@ -155,7 +179,7 @@ WWW::Ohloh::API::Stack - a collection of projects used by a person
     my $ohloh = WWW::Ohloh::API->new( api_key => $my_api_key );
 
     # get the stack of a person
-    my $stack = $ohloh->get_account_stack( $account_id );
+    my $stack = $ohloh->fetch_account_stack( $account_id );
 
     # get stacks containing a project
     my @stacks = $ohloh->get_project_stacks( $project_id );
@@ -261,7 +285,7 @@ Ohloh Account API reference: http://www.ohloh.net/api/reference/stack
 
 =head1 VERSION
 
-This document describes WWW::Ohloh::API version 0.3.2
+This document describes WWW::Ohloh::API version 1.0_0
 
 =head1 BUGS AND LIMITATIONS
 
